/*
 * Copyright 1999-2101 Alibaba Group.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.fastjson.serializer;

import java.io.IOException;
import java.util.Map;

/**
 * 
 * @author wenshao<szujobs@hotmail.com>
 * 
 */
public class MapSerializer extends ObjectSerializer {
	public static MapSerializer instance = new MapSerializer();

	@Override
	public void write(JSONSerializer serializer, Object object) throws IOException {
		SerializeWriter out = serializer.getWrier();
		
		Map<?, ?> map = (Map<?, ?>) object;

		out.write('{');
		
		Class<?> preClazz = null;
		ObjectSerializer preWriter = null;

		boolean first = true;
		for (Map.Entry<?, ?> entry : map.entrySet()) {
			Object value = entry.getValue();

			if (value == null) {
				if (!serializer.isEnabled(SerializerFeature.WriteMapNullValue)) {
					continue;
				}
			}

			if (!first) {
				out.write(',');
			}

			Object entryKey = entry.getKey();
			String key = entryKey == null ? "null" : entryKey.toString();
			if (serializer.isEnabled(SerializerFeature.UseSingleQuotes)) {
				if (serializer.isEnabled(SerializerFeature.QuoteFieldNames)) {
					out.writeKeyWithSingleQuote(key);
				} else {
					out.writeKeyWithSingleQuoteIfHashSpecial(key);
				}
			} else {
				if (serializer.isEnabled(SerializerFeature.QuoteFieldNames)) {
					out.writeKeyWithDoubleQuote(key);
				} else {
					out.writeKeyWithDoubleQuoteIfHashSpecial(key);
				}
			}
			first = false;

			if (value == null) {
				out.write("null");
				continue;
			}

		
			Class<?> clazz = value.getClass();
			
			if (clazz == preClazz) {
				preWriter.write(serializer, value);
			} else {
				preClazz = clazz;
				preWriter = serializer.getObjectWriter(clazz);
				
				preWriter.write(serializer, value);
			}
		}
		out.write('}');
	}
}