/*
 * Copyright 1999-2101 Alibaba Group.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.fastjson.serializer;

import java.io.IOException;

/**
 * 
 * @author wenshao<szujobs@hotmail.com>
 * 
 */
public class ObjectArraySerializer extends ObjectSerializer {
	public static final ObjectArraySerializer instance = new ObjectArraySerializer();

	public ObjectArraySerializer() {
	}

	public final void write(JSONSerializer serializer, Object object) throws IOException {
		SerializeWriter out = serializer.getWrier();
		
		Object[] array = (Object[]) object;
		int size = array.length;

		int end = size - 1;

		if (end == -1) {
			out.append("[]");
			return;
		}

		Class<?> preClazz = null;
		ObjectSerializer preWriter = null;
		out.append('[');
		for (int i = 0; i < end; ++i) {
			Object item = array[i];

			if (item == null) {
				out.append("null,");
			} else {
				Class<?> clazz = item.getClass();
				
				if (clazz == preClazz) {
					preWriter.write(serializer, item);
				} else {
					preClazz = clazz;
					preWriter = serializer.getObjectWriter(clazz);
					
					preWriter.write(serializer, item);
				}
				
				out.append(',');
			}
		}

		Object item = array[end];

		if (item == null) {
			out.append("null]");
		} else {
			serializer.write(item);
			out.append(']');
		}
	}
}